==> esp32s3-0.1.0.crate: esp32s3-0.1.0/src/wcl/core_0_world_phase.rs <==
#[doc = "Register `Core_0_World_Phase` reader"]
pub struct R(crate::R<CORE_0_WORLD_PHASE_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CORE_0_WORLD_PHASE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CORE_0_WORLD_PHASE_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CORE_0_WORLD_PHASE_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `CORE_0_WORLD_PHASE` reader - This bit indicates whether is preparing to switch to WORLD1, 1 means value."]
pub struct CORE_0_WORLD_PHASE_R(crate::FieldReader<bool, bool>);
impl CORE_0_WORLD_PHASE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CORE_0_WORLD_PHASE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CORE_0_WORLD_PHASE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bit 0 - This bit indicates whether is preparing to switch to WORLD1, 1 means value."]
    #[inline(always)]
    pub fn core_0_world_phase(&self) -> CORE_0_WORLD_PHASE_R {
        CORE_0_WORLD_PHASE_R::new((self.bits & 0x01) != 0)
    }
}
#[doc = "Core_0 world status register\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [core_0_world_phase]
(index.html) module"]
pub struct CORE_0_WORLD_PHASE_SPEC;
impl crate::RegisterSpec for CORE_0_WORLD_PHASE_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [core_0_world_phase::R]
(R) reader structure"]
impl crate::Readable for CORE_0_WORLD_PHASE_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets Core_0_World_Phase to value 0"]
impl crate::Resettable for CORE_0_WORLD_PHASE_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32s3-0.2.0.crate: esp32s3-0.2.0/src/wcl/core_0_world_phase.rs <==
#[doc = "Register `Core_0_World_Phase` reader"]
pub struct R(crate::R<CORE_0_WORLD_PHASE_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CORE_0_WORLD_PHASE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CORE_0_WORLD_PHASE_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CORE_0_WORLD_PHASE_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `CORE_0_WORLD_PHASE` reader - This bit indicates whether is preparing to switch to WORLD1, 1 means value."]
pub struct CORE_0_WORLD_PHASE_R(crate::FieldReader<bool, bool>);
impl CORE_0_WORLD_PHASE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        CORE_0_WORLD_PHASE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CORE_0_WORLD_PHASE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bit 0 - This bit indicates whether is preparing to switch to WORLD1, 1 means value."]
    #[inline(always)]
    pub fn core_0_world_phase(&self) -> CORE_0_WORLD_PHASE_R {
        CORE_0_WORLD_PHASE_R::new((self.bits & 1) != 0)
    }
}
#[doc = "Core_0 world status register\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [core_0_world_phase]
(index.html) module"]
pub struct CORE_0_WORLD_PHASE_SPEC;
impl crate::RegisterSpec for CORE_0_WORLD_PHASE_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [core_0_world_phase::R]
(R) reader structure"]
impl crate::Readable for CORE_0_WORLD_PHASE_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets Core_0_World_Phase to value 0"]
impl crate::Resettable for CORE_0_WORLD_PHASE_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
